%bcond_without tests
# Currently, the Sphinx documentation does not contain anything useful.
%bcond_with sphinx

Name:           gaupol
Version:        0.19.2
Release:        7%{?dist}
Summary:        Editor for text-based subtitle files

# Everything is GPLv3+, except:
#   data/iso-codes, which is LGPLv2+; however, we treat this as a bundled
#   dependency and remove it, so the packages are not affected by its license,
# and:
#   data/extensions/bookmarks/bookmark.png, which is GPLv2+ (copied from anjuta
#   between 2007-2015).
# See the CREDITS file.
License:        GPLv3+ and GPLv2+
URL:            https://otsaloma.io/%{name}/
Source0:        https://github.com/otsaloma/%{name}/archive/%{version}.tar.gz

BuildArch:      noarch


BuildRequires:  python2-devel
# Note that this package does not (yet) require setuptools!

BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  intltool

%if %{with tests}
# “Gaupol requires Python [1] 2.6 or greater and PyGTK [2] 2.16 or
# greater.”
BuildRequires:  pygobject2 >= 2.16
BuildRequires:  gtk2 >= 2.16
# “Optional dependencies include: gst-python [3] and pocketsphinx [4] --
# required for speech recognition;” (not available in EPEL7)
#
# “PyEnchant [5] 1.4.0 or greater -- required for spell-checking;”
BuildRequires:  python-enchant >= 1.4.0
# “PyGtkSpell (part of gnome-python-extras [2]) -- required for inline
# spell-checking;”
BuildRequires:  gnome-python2-gtkspell
# “iso-codes [6] -- required to translate language and country names;”
BuildRequires:  iso-codes
# “Universal Encoding Detector [7] -- required for character encoding
# auto-detection”
BuildRequires:  python-chardet
# “and MPlayer [8] or VLC [9] -- recommended for preview.” (not available in
# EPEL7)

BuildRequires:  python2-pytest
# Tests involving gtk.show_uri() require a browser, any browser:
BuildRequires:  firefox
%endif

%if %{with tests} || %{with sphinx}
# Support graphical tests in non-graphical environment
BuildRequires:  xorg-x11-server-Xvfb
%endif

# For /usr/share/icons/hicolor/*/apps
Requires:       hicolor-icon-theme

Requires:       pygobject2 >= 2.16
Requires:       gtk2 >= 2.16
# Note that all optional dependencies are made mandatory since we do not have
# Recommends, and that iso-codes is not actually optional since we unbundled
# it.
Requires:       python-enchant >= 1.4.0
Requires:       gnome-python2-gtkspell
Requires:       iso-codes
Requires:       python-chardet

Requires:       python2-aeidon = %{version}-%{release}

# https://fedoraproject.org/wiki/EPEL:Packaging#desktop-database
Requires(post):         desktop-file-utils
Requires(postun):       desktop-file-utils


%description
Gaupol is an editor for text-based subtitle files. It helps you with tasks such
as creating and translating subtitles, timing subtitles to match video and
correcting common errors. Gaupol includes a built-in video player and also
supports launching an external one.

Gaupol is available for Linux and Windows, released as Free Software under the
GNU General Public License (GPL). Gaupol’s user interface is based on the GTK 2
toolkit and has been designed to best fit the GNOME desktop environment.


%package doc
Summary:        Documentation for %{name}
# No data/extensions/bookmarks/bookmark.png, so no GPLv2+
License:        GPLv3+

%if %{with sphinx}
BuildRequires:  python2-sphinx
BuildRequires:  make
%endif

%description doc
Documentation for %{name}.


%package -n python2-aeidon
Summary:        Read, write, and manipulate text-based subtitle files
# No data/extensions/bookmarks/bookmark.png, so no GPLv2+
License:        GPLv3+

Provides:       aeidon = %{version}-%{release}
Obsoletes:      aeidon < 0.19.2-6
Conflicts:      aeidon < 0.19.2-6

Requires:       python-enchant >= 1.4.0
Requires:       iso-codes
Requires:       python-chardet

%{?python_provide:%python_provide python2-aeidon}

%global py_setup_args --without-iso-codes

%description -n python2-aeidon
aeidon is a Python package for reading, writing and manipulating text-based
subtitle files. It is used by the %{name} package, which provides a subtitle
editor application with a GTK+ user interface.

Separating a user-interface independent general-purpose subtitle editing
package from Gaupol has been an afterthought and thus not well designed to be a
reusable component, but on the other hand is proven, working and maintained
code.

API Documentation: https://otsaloma.io/gaupol/doc/api/aeidon.html


%prep
%autosetup
# Remove bundled iso-codes:
find data/iso-codes -type f -name '*.xml' |
  while read -r fn
  do
    ln -svf "%{_datadir}/xml/iso-codes/$(basename "${fn}")" "${fn}"
  done


%build
%py2_build
%if %{with sphinx}
pushd doc/sphinx
%{_bindir}/xvfb-run %{__python2} ./autogen.py
%{_bindir}/xvfb-run %make_build html
popd
%endif


%install
%py2_install
%find_lang %{name}
desktop-file-install \
    --dir=%{buildroot}%{_datadir}/applications \
    --delete-original \
    --add-category='AudioVideoEditing' \
    %{buildroot}/%{_datadir}/applications/%{name}.desktop


%post
# https://fedoraproject.org/wiki/EPEL:Packaging#desktop-database
/usr/bin/update-desktop-database &> /dev/null || :
# https://fedoraproject.org/wiki/EPEL:Packaging#Icon_Cache
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
# https://fedoraproject.org/wiki/EPEL:Packaging#desktop-database
/usr/bin/update-desktop-database &> /dev/null || :
# https://fedoraproject.org/wiki/EPEL:Packaging#Icon_Cache
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%check
if [ "$(find data/iso-codes -type f ! -name 'README*' | wc -l)" != 0 ]
then
  echo 'Failed to fully remove bundled iso-codes' 1>&2
  false
fi

%if %{with tests}
# Two failures and one hang, respectively, that we are not going to attempt to
# diagnose. Patches welcome if anyone cares.
k='not (TestCalculator and test_get_middle__time)'
k="${k} and not (TestModule and test_get_all)"
k="${k} and not (TestPreviewAgent and test_preview__unicode_error)"
# Tests that would require a network connection to an Internet host:
k="${k} and not (TestModule and test_bug_report_url)"
k="${k} and not (TestModule and test_extensions_url)"
k="${k} and not (TestModule and test_homepage_url)"
k="${k} and not (TestModule and test_preview_help_url)"
k="${k} and not (TestModule and test_regex_help_url)"
k="${k} and not (TestModule and test_speech_recognition_help_url)"
k="${k} and not (TestModule and test_wiki_url)"
# Tests that would require the optional gst-python dependency:
k="${k} and not (TestModule and test_get_gst_version)"
k="${k} and not (TestModule and test_get_pygst_version)"
k="${k} and not (TestModule and test_gst_available)"

%{_bindir}/xvfb-run -a %{__python2} -m pytest --verbose -k "${k}"
%endif


%files -f %{name}.lang
%license COPYING
%license CREDITS

%{_bindir}/%{name}

%{python2_sitelib}/%{name}
%{python2_sitelib}/%{name}-%{version}-py%{python2_version}.egg-info

%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
%{_datadir}/icons/hicolor/22x22/apps/%{name}.png
%{_datadir}/icons/hicolor/24x24/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_mandir}/man1/gaupol.1*


%files doc
%license COPYING
%license CREDITS
%doc AUTHORS
%doc README
%doc NEWS
%doc TODO
%doc doc/formats
%if %{with sphinx}
%doc doc/sphinx/_build/html
%endif
%doc doc/wiki


%files -n python2-aeidon
%license COPYING
%license CREDITS
%doc AUTHORS
%doc README.aeidon
%doc NEWS
%doc TODO

%{python2_sitelib}/aeidon


%changelog
* Tue Dec 22 2020 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.2-7
- Disable Sphinx documentation, as it contains nothing useful

* Tue Dec 22 2020 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.2-6
- Update URL
- Get source tarball from GitHub instead of defunct gna.org
- Stop using unversioned Python macros and dependencies
- Drop obsolete RPM practices (defattr, removing buildroot, explicit BuildRoot
  path, Group field)
- Unbundle iso-codes data dependency
- Use modern RPM macros throughout, to the extent supported by EPEL7
- Update summaries and descriptions from upstream
- Enable test suite
- Rename aeidon subpackage to python2-aeidon
- More detailed and accurate dependencies and BR’s
- Make dependency on python2-aeidon subpackage require the exact matching
  version and release

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.19.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Dec 07 2011 Lucian Langa <cooly@gnome.eu.org> - 0.19.2-1
- new upstream release

* Mon Sep 26 2011 cooly@gnome.eu.org - 0.19.1-1
- new upstream release

* Sun Jul 31 2011 Lucian Langa <cooly@gnome.eu.org> - 0.19-1
- new upstream release

* Sat Jun 18 2011 Lucian Langa <cooly@gnome.eu.org> - 0.18-1
- new upstream release

* Sun Apr 24 2011 Lucian Langa <cooly@gnome.eu.org> - 0.17.2-1
- drop version from supackage (to match main version)
- new upstream release

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.17.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Dec 18 2010 Lucian Langa <cooly@gnome.eu.org> - 0.17.1-1
- new upstream release

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 0.17-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Jul 08 2010 Lucian Langa <cooly@gnome.eu.org> - 0.17-1
- new supackage aeidon the subtitle engine
- new upstream release

* Fri Apr 02 2010 Lucian Langa <cooly@gnome.eu.org> - 0.15.1-1
- update to 0.15.1

* Sun Sep 27 2009 Orcan Ogetbil <oget[DOT]fedora[AT]gmail[DOT]com> - 0.15-5
- Update desktop file according to F-12 FedoraStudio feature

* Mon Aug 10 2009 Ville Skyttä <ville.skytta@iki.fi> - 0.15-4
- Use bzipped upstream tarball.

* Sun Aug 02 2009 Lucian Langa <cooly@gnome.eu.org> - 0.15-3
- do not remove required file (b.g.o #590537)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon May 18 2009 Lucian Langa <cooly@gnome.eu.org> - 0.15-1
- add python-chardet as requirement
- new upstream release

* Mon Apr 13 2009 Lucian Langa <cooly@gnome.eu.org> - 0.14-1
- fix Source url
- new upstream release

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jan 15 2009 Lucian Langa <cooly@gnome.eu.org> - 0.13.1-1
- initial package


